pub struct Metrics {
pub nr_direct_dispatches: u64,
pub nr_shared_enqueues: u64,
pub nr_idle_kicks: u64,
pub nr_local_llc: u64,
pub nr_remote_llc: u64,
}Fields
nr_direct_dispatches: u64Number of tasks dispatched directly to an idle cid
Number of tasks queued to the shared FIFO
nr_idle_kicks: u64Number of idle cids kicked to consume the shared FIFO
nr_local_llc: u64Number of idle cids picked in the previous LLC
nr_remote_llc: u64Number of idle cids picked outside of the previous LLC
Implementations